@@ -1,8 +1,8 @@
-cSS = function(K, rx, eps = 1e-8)
+cSS = function(K, rx, m = 0, eps=1e-8)
 {
   b = rx$coefficients
   iiv = G2SWEEP(K %*% rx$g2 %*% t(K), Augmented=FALSE, eps=eps)
-  Kb = K %*% b
+  Kb = K %*% b - m
   Q = t(Kb) %*% iiv %*% Kb
   Df = attr(iiv, "rank")
   MS = ifelse(Df > 0, Q/Df, NA)
@@ -13,6 +13,7 @@ cSS = function(K, rx, eps = 1e-8)
     Fval = NA
     Pval = NA
   }
-  Result = c(Df=Df, 'Sum Sq'=Q, 'Mean Sq'=MS, 'F value'=Fval, 'Pr(>F)'=Pval)
+  Result = data.frame(Df, Q, MS, Fval, Pval)
+  colnames(Result) = c("Df", "Sum Sq", "Mean Sq", "F value", "Pr(>F)")
   return(Result)
 }
